#!/bin/sh
# Licensed Materials - Property of IBM and/or HCL Confidential
# Rational ClearQuest 
# (C) Copyright IBM Corp. 2010, 2016.  All Rights Reserved.
# (C) Copyright HCL Technologies Ltd. 2017.  All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#
# Run this batch file to copy the Eclipse plugins of the reporting driver from the shared Installation
# Manager directory to a target directory
# Usage:   
#  copyDriverPlugins <no arguments>   - Copies the ClearQuest driver plugins to the current directory
#  copyDriverPlugins <targetDirectory> - Copies the ClearQuest driver plugins to the targetDirectory    
#  copyDriverPlugins clean - Removes existing ClearQuest driver plugins and jar files.  When this option is used, 
#     the current directory is treated as the targetDirectory. 

usage()
{
   set echo
   echo copyDriverPlugins usage:
   echo    copyDriverPlugins "usage" prints this message
   echo  copyDriverPlugins "clean" removes previously copied ClearQuest Reporting Driver files
   echo    copyDriverPlugins "<target directory>"
   unset echo
   exit 0
}

cleanForUpdate()
{
   cleanJ2EE
   echo Complete the cleanup.
   clearSettings
   exit 0
}

clean() 
{
   # Get the last token of the working directory to determine the type of BIRT deployment
   local path_length=`expr length $PWD`
   local start_index=`expr $path_length - 3`
   local suffix=`expr substr $PWD  $start_index $path_length`
   if [ $suffix = "/lib" ]; then 
      cleanJ2EE
   else
      cleanOSGi
   fi
}

cleanJ2EE() 
{
   echo Removing ClearQuest Reporting Driver files

   rm $TARGET_PATH/com.ibm.rational.clearquest.*.jar
   rm $TARGET_PATH/stpwvcm.jar
   rm $TARGET_PATH/stpcmmn.jar
   rm $TARGET_PATH/stpcq.jar
   rm $TARGET_PATH/cqjni.jar
   rm $TARGET_PATH/commons-httpclient-3.0.1.jar
   rm $TARGET_PATH/commons-codec-1.3.jar
   rm $TARGET_PATH/commons-codec-1.10.jar
   rm $TARGET_PATH/httpclient-4.5.2.jar
   rm $TARGET_PATH/httpmime-4.5.2.jar
   rm $TARGET_PATH/httpcore-4.4.4.jar

   cleanRename
}

cleanRename()
{
   if [ $BIRT_VER_FOUND -lt "4" ]; then
      echo Restoring $TARGET_PATH/axis.jar from $TARGET_PATH/axis.jar.backup
      mv $TARGET_PATH/axis.jar.backup $TARGET_PATH/axis.jar

      local saved_name=$(findLatestJar "$TARGET_PATH/org.apache.xml.serializer_*.jar.backup" ) 
      local path_length=`expr length $saved_name`
      local start_index=`expr $path_length - 7`
      local restore_name=`expr substr $saved_name  1 $start_index`
      echo Restoring $restore_name from $saved_name
      mv $saved_name $restore_name

      saved_name=$(findLatestJar "$TARGET_PATH/org.apache.xerces_*.jar.backup" ) 
      path_length=`expr length $saved_name`
      start_index=`expr $path_length - 7`
      restore_name=`expr substr $saved_name  1 $start_index`
      echo Restoring $restore_name from $saved_name
      mv $saved_name $restore_name
   fi
}

cleanOSGi() 
{
   echo Removing ClearQuest Reporting Driver plugins

   rm -rf $CQ_CORE_LIB*
   rm -rf $CM_LIBRARY*
   rm -rf $CQ_JDBC*
   rm -rf $ODA_JDBC*
   rm -rf $ODA_JDBC_NL*
}

# Clear settings established by initializeSettings
clearSettings()
{
   unset PLUGIN_PATH
   unset CQ_CORE_LIB
   unset CQ_JDBC
   unset CM_LIBRARY
   unset ODA_JDBC
   unset ODA_JDBC_NL
   unset TARGET_PATH

   unset BIRT_3_RUNTIME
   unset BIRT_4_RUNTIME
   unset BIRT_VER_FOUND

   exit 0
}

copy()
{
   set echo
   # Get the last token of the TARGET_PATH to determine the type of BIRT deployment
   local path_length=`expr length $TARGET_PATH`
   local start_index=`expr $path_length - 3`
   local suffix=`expr substr $TARGET_PATH  $start_index $path_length`
   if [ "$suffix" = "/lib" ]; then 
      copyJ2EE
   else
      copyOSGi
   fi
   unset echo
}

copyJ2EE()
{
   echo $PLUGIN_PATH
   echo Copying driver archive files to $TARGET_PATH
   local RATIONAL_COMMON=/opt/rational/common
   local CLEARQUEST_HOME=/opt/rational/clearquest

   echo Extracting httpclient jar files from plugin $LATEST_PLUGIN
   unzip $PLUGIN_PATH/com.ibm.rational.stp_*.jar commons-codec-1.10.jar -d $TARGET_PATH 
   unzip $PLUGIN_PATH/com.ibm.rational.stp_*.jar httpclient-4.5.2.jar -d $TARGET_PATH 
   unzip $PLUGIN_PATH/com.ibm.rational.stp_*.jar httpmime-4.5.2.jar -d $TARGET_PATH
   unzip $PLUGIN_PATH/com.ibm.rational.stp_*.jar httpcore-4.4.4.jar -d $TARGET_PATH 

   echo Copying stpcmmn.jar and stpwvcm.jar from $RATIONAL_COMMON
   cp $RATIONAL_COMMON/stpcmmn.jar $TARGET_PATH
   cp $RATIONAL_COMMON/stpwvcm.jar $TARGET_PATH

   echo Copying stpcq.jar from $CLEARQUEST_HOME
   cp $CLEARQUEST_HOME/stpcq.jar $TARGET_PATH
   echo Copying cqjni.jar from $CLEARQUEST_HOME
   cp $CLEARQUEST_HOME/cqjni.jar $TARGET_PATH

   echo Copying com.ibm.rational.clearquest.jdbc*.jar from $CLEARQUEST_HOME
   cp $PLUGIN_PATH/com.ibm.rational.clearquest.jdbc*.jar $TARGET_PATH

   echo Copying com.ibm.rational.clearquest.oda.jdbc*.jar from $CLEARQUEST_HOME
   cp $PLUGIN_PATH/com.ibm.rational.clearquest.oda.jdbc_*.jar $TARGET_PATH
   cp $PLUGIN_PATH/com.ibm.rational.clearquest.oda.jdbc.nl*.jar $TARGET_PATH 

   if [ $BIRT_VER_FOUND -lt "4" ]; then
      echo Renaming axis.jar to axis.jar.backup
      mv $TARGET_PATH/axis.jar $TARGET_PATH/axis.jar.backup

      LATEST_PLUGIN=$(findLatestJar "$TARGET_PATH/org.apache.xml.serializer_*.jar" ) 
      echo Renaming $LATEST_PLUGIN to $LATEST_PLUGIN.backup
      mv $LATEST_PLUGIN $LATEST_PLUGIN.backup

      LATEST_PLUGIN=$(findLatestJar "$TARGET_PATH/org.apache.xerces_*.jar" ) 
      echo Renaming $LATEST_PLUGIN to $LATEST_PLUGIN.backup
      mv $LATEST_PLUGIN $LATEST_PLUGIN.backup
   fi
}

copyOSGi()
{
   echo Copying driver plugins from $PLUGIN_PATH to $TARGET_PATH
   cp -r $PLUGIN_PATH/$CQ_CORE_LIB* $TARGET_PATH
   cp -r $PLUGIN_PATH/$CQ_JDBC* $TARGET_PATH
   cp -r $PLUGIN_PATH/$CM_LIBRARY* $TARGET_PATH
   cp -r $PLUGIN_PATH/$ODA_JDBC* $TARGET_PATH
   cp -r $PLUGIN_PATH/$ODA_JDBC_NL* $TARGET_PATH
}

findLatestDir()
{
   echo `ls -t1d $1 | tail -n1`
}

findLatestJar()
{
   echo `ls -t1 $1 | tail -n1`
}

# Initialize settings used during script processing.
# PLUGIN_PATH can be changed if a nondefault installation path is used
initializeSettings()
{
   PLUGIN_PATH=/opt/rational/clearquest/reports/driver/plugins
   CQ_CORE_LIB=com.ibm.rational.clearquest.core.lib
   CQ_JDBC=com.ibm.rational.clearquest.jdbc
   CM_LIBRARY=com.ibm.rational.stp
   ODA_JDBC=com.ibm.rational.clearquest.oda.jdbc_
   ODA_JDBC_NL=com.ibm.rational.clearquest.oda.jdbc.nl1

   BIRT_3_RUNTIME=org.eclipse.birt.runtime_3
   BIRT_4_RUNTIME=org.eclipse.birt.runtime_4
   BIRT_VER_FOUND=
}

# Figures out and sets the BIRT version in use.
detectBIRTruntimeVersion()
{
   echo Looking for BIRT runtime in: $1

   if [ -z ${CQ_BIRT_VERSION} ]; then
      local BIRT_RUNTIME_FOUND=$(findBIRTruntimeFile $1/$BIRT_3_RUNTIME*.jar)
      if [ ! -z ${BIRT_RUNTIME_FOUND} ]; then
         BIRT_VER_FOUND=3
      else
         local BIRT_RUNTIME_FOUND=$(findBIRTruntimeFile $1/$BIRT_4_RUNTIME*.jar)
         if [ ! -z ${BIRT_RUNTIME_FOUND} ]; then
            BIRT_VER_FOUND=4
         fi
      fi

      if [ ! -z ${BIRT_VER_FOUND} ]; then
         echo Found BIRT runtime version: $BIRT_VER_FOUND
      else
         BIRT_VER_FOUND=4
         echo "WARNING: Cannot detect BIRT version, assuming version 4.x."
         echo "         If you know the version of BIRT and want to force it, set the"
         echo "         environment variable 'CQ_BIRT_VERSION' to the major version of"
         echo "         BIRT such as: CQ_BIRT_VERSION=3 or CQ_BIRT_VERSION=4."
      fi
   else
      BIRT_VER_FOUND=$CQ_BIRT_VERSION
      echo "Using custom provided BIRT version: $BIRT_VER_FOUND"
   fi
}

# Looks for and set the BIRT runtime JAR file name.
findBIRTruntimeFile()
{
   echo `ls -t1 $1 | tail -n1`
}


if [ "$1" = "usage" ]; then usage
   exit 0
fi

initializeSettings

if [ "$1" = "clean" ]; then 
   if [ $2 ]; then
      TARGET_PATH=$2
      detectBIRTruntimeVersion $TARGET_PATH
      cleanForUpdate
   fi
   clean
   clearSettings
   exit 0
fi

if [ $# -eq 0 ]; then 
   TARGET_PATH=$PWD
else
   TARGET_PATH=$1
fi

detectBIRTruntimeVersion $TARGET_PATH

copy
clearSettings
exit 0
