@echo off
rem #
rem # Licensed Materials - Property of IBM and/or HCL Confidential
rem # Rational ClearQuest 
rem # (C) Copyright IBM Corp. 2013,2016 All Rights Reserved
rem # (C) Copyright HCL Technologies Ltd. 2017.  All Rights Reserved.
rem # US Government Users Restricted Rights -
rem # Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
rem #
rem # The source code for this program is not published or otherwise
rem # divested of its trade secrets, irrespective of what has been
rem # deposited with the U.S. Copyright Office.
rem #
rem # Run this batch file to deploy birt.war runtime, customize settings, and copy
rem # the ClearQuest reporting driver plugins and jars to the BIRT runtime
rem #
rem # Usage:   
rem #  deployBIRT.bat <no arguments>   ->Deploy default "birt.war" file to default WebSphere Application Server profile, customize the settings
rem #  for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.
rem #  deployBIRT.bat <war_file>   ->Deploy the passed birt war file to default WebSphere Application Server profile, customize the settings
rem #  for usage with ClearQuest, and copy the ClearQuest Reporting Driver files.
rem #  deployBIRT.bat -update <birt_war_name>   ->Update the birt war application to default WebSphere Application Server profile, customize the settings
rem #  for usage with ClearQuest, clean up old ClearQuest Reporting Driver files and copy new ClearQuest Reporting Driver files.
rem #  deployBIRT.bat -update <no arguments>   ->Use the default birt_war_name "birt.war" to do update.

setlocal
:start
rem set WAS_PROFILE_PATH=C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\AppSrv01
rem set WAS_PROFILE_PATH=%CLEARQUEST_HOME%\cqweb\cqwebprofile
set WAS_PROFILE_PATH=%CLEARQUEST_HOME%\cqweb\cqwebprofile
set BIRT_DRIVER_PATH=
set WAR_FILE=
rem set PERL_PATH=C:\Program Files (x86)\IBM\RationalSDLC\common\CQperl.exe
set PERL_PATH=%RATIONAL_COMMON%/CQperl.exe
set RESTARTWAS=NO

if "%1" == "usage" (
   @echo Usage:
   @echo   deployBIRT.bat ^<no arguments^>
   @echo       Deploy default "birt.war" file to default WebSphere Application Server
   @echo       profile.  Customize the settings for usage with ClearQuest, and copy 
   @echo       the ClearQuest Reporting Driver files.
   @echo   deployBIRT.bat ^<war_file^>
   @echo       Deploy the passed BIRT WAR file to default WebSphere Application Server 
   @echo       profile.  Customize the settings for usage with ClearQuest, and copy 
   @echo       the ClearQuest Reporting Driver files.
   @echo   deployBIRT.bat -update ^<birt_war_name^>
   @echo       Update the BIRT WAR application to default WebSphere Application Server 
   @echo       profile.  Customize the settings for usage with ClearQuest, clean up old 
   @echo       ClearQuest Reporting Driver files and copy new ClearQuest Reporting Driver
   @echo       files.
   @echo   deployBIRT.bat -update ^<no arguments^>
   @echo       Use the default birt_war_name "birt.war" to do update.
   goto :end
)

if not [%2]==[] set WAR_FILE=%2
if "%1" == "-update" goto doUpdate
if [%1]==[] goto setdefault
set WAR_FILE=%1
goto deployBIRT

:doUpdate
if "%WAR_FILE%"=="" set WAR_FILE=birt.war
if not exist "%WAS_PROFILE_PATH%" (
	@echo The path of WAS_PROFILE_PATH does not exist.
	@echo Please open this file and correct the WAS_PROFILE_PATH before update.
	goto :end
)

set LOCAL_PATH="%WAS_PROFILE_PATH%\installedApps\*.*"
call :getCellPath %LOCAL_PATH%

if not exist "%CELL_PATH%\birt_war.ear\%WAR_FILE%" (
	@echo Error: The birt war name does not exist. Please correct and try again.
	goto :end
)

if exist "%PERL_PATH%" (
	goto updateReportlauncher
) else (
	@echo Error: The PERL_PATH does not exist. Please correct it and try again.
)
goto :end

:updateReportlauncher
set RESTARTWAS=YES
set REPORTLAUNCHER_PATH=%CELL_PATH%\RationalClearQuestReportLauncher.ear\CQReportLauncher.war\WEB-INF\classes\reportlauncher.properties
if not exist "%REPORTLAUNCHER_PATH%" (
	@echo Error: WAS_PROFILE_PATH does not exist. Please correct WAS_PROFILE_PATH and try again.
	goto :end
)
"%PERL_PATH%" -pi.bak -e "s/\/birt\/frameset/\/birt\/cqbirt.jsp/g" "%REPORTLAUNCHER_PATH%"
if errorlevel 1 @echo Error: reportlauncher.properties file is updated failed. Please correct PERL_PATH and REPORTLAUNCHER_PATH and try again.
if errorlevel 0 @echo reportlauncher.properties file is updated successfully.
goto updateBIRT

:updateBIRT
echo Start to update BIRT JSP file and driver plugin
if "%WAR_FILE%"=="" set WAR_FILE=birt.war
if "%BIRT_DRIVER_PATH%"=="" goto setDefaultBIRTPath
goto setBIRTWARPath
goto :end

:setdefault
set WAR_FILE=birt.war
goto deployBIRT

:deployBIRT
@echo Calling wsadmin to deploy %WAR_FILE%
CALL "%WAS_PROFILE_PATH%\bin\wsadmin.bat" -lang jython -f deployBIRT.py %WAR_FILE% -wsadmin_classpath ./deployBIRT.jar
if "%BIRT_DRIVER_PATH%"=="" goto setDefaultBIRTPath

goto setBIRTWARPath

:setDefaultBIRTPath
   set TEMP_PATH="%WAS_PROFILE_PATH%\installedApps"
   call :getCellPath %TEMP_PATH%\*.*
   set TEMP_PATH=%CELL_PATH%\birt_war.ear\%WAR_FILE%\WEB-INF
   set BIRT_WAR_HOME="%CELL_PATH%\birt_war.ear\%WAR_FILE%"
   if exist "%TEMP_PATH%\platform" (
      set BIRT_DRIVER_PATH="%TEMP_PATH%\platform\plugins"
   ) else (
	  set BIRT_DRIVER_PATH="%TEMP_PATH%\lib"
   )
   goto copyJSP

:setBIRTWARPath
   set TEMP_PATH="%WAS_PROFILE_PATH%\installedApps"
   call :getCellPath %TEMP_PATH%\*.*
   set BIRT_WAR_HOME="%CELL_PATH%\birt_war.ear\%WAR_FILE%"
   goto copyJSP
   
:copyDriverPlugins
@echo Attempting to clean up certain files, some may not exist, this is expected.
CALL copyDriverPlugins.bat clean %BIRT_DRIVER_PATH%
@echo Calling copyDriverPlugins with target path %BIRT_DRIVER_PATH%
CALL copyDriverPlugins.bat %BIRT_DRIVER_PATH%
if "%RESTARTWAS%"=="YES" goto restartwas
goto :end

:copyJSP
@echo Calling copyJSP with target path %BIRT_WAR_HOME%
if not exist "%CELL_PATH%\birt_war.ear\%WAR_FILE%" (
	@echo Error: The birt war name does not exist. Please correct and try again.
) else (
	CALL copyJSP.bat %BIRT_WAR_HOME%
)
goto copyDriverPlugins

:restartwas
@echo Update is completed. Now please manually restart BIRT WAR and Report Launcher applications under the profile: %WAS_PROFILE_PATH%
goto :end

rem Set variable CELL_PATH to a subdirectory of the passed directory path
:getCellPath
for /D %%I in (%1) do set "CELL_PATH=%%I"
goto :eof

:end
endlocal
